Module groups_api

Module groups_api 

Enums

CreateGroupError
struct for typed errors of method create_group
DeleteGroupError
struct for typed errors of method delete_group
GetGroupError
struct for typed errors of method get_group
ListGroupsError
struct for typed errors of method list_groups

Functions

create_group
Create a group that perform CRUD operations on workflow resources. The owner of the group will be made an admin by default. If you want to set other users as admins, you must use the ‘’ endpoint.
delete_group
Delete a group and all of the objects that belong to them
get_group
Retrieve details for a given group id
list_groups
Retrieve all groups to which the user belongs