create_group

Function create_group 

pub async fn create_group(
    configuration: &Configuration,
    req_group: ReqGroup,
) -> Result<RespResourceUrl, Error<CreateGroupError>>
Create a group that perform CRUD operations on workflow resources. The owner of the group will be made an admin by default. If you want to set other users as admins, you must use the ‘’ endpoint.