Enums
- Create
Group Error - struct for typed errors of method
create_group - Delete
Group Error - struct for typed errors of method
delete_group - GetGroup
Error - struct for typed errors of method
get_group - List
Groups Error - struct for typed errors of method
list_groups
Functions
- create_
group - Create a group that perform CRUD operations on workflow resources. The owner of the group will be made an admin by default. If you want to set other users as admins, you must use the ‘’ endpoint.
- delete_
group - Delete a group and all of the objects that belong to them
- get_
group - Retrieve details for a given group id
- list_
groups - Retrieve all groups to which the user belongs